package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`MP`!````T"1```````!``````````&C#````
M`````````$``.``'`$``&P`:``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````-RW````````W+<`````````
M``$```````$````&````P+T```````#`O4$``````,"]00``````D`0`````
M``#H%````````````0```````@````8```#8O0```````-B]00``````V+U!
M`````````@`````````"````````"``````````$````!````.0!````````
MY`%```````#D`4```````$0`````````1``````````$`````````%+E=&0$
M````P+T```````#`O4$``````,"]00``````0`(```````!``@````````$`
M````````+VQI8B]L9"UL:6YU>"UA87)C:#8T+G-O+C$```0````0`````0``
M`$=.50```````P````<`````````!````!0````#````1TY5`$4$$/9>$`^W
MAE0D:P-E4"2^PL<&80````4````0````"@```*`0`"@"1A$```!@`%8"4!B"
M"`0@2``1$0`($`(`(`````````!(`B`.``L``(0"J$$(!2!H",1).$(4E09!
M*`HH6(B!!6`$E@@)0DIP0``8`0%!0P@`0(",P`0`"!"0$`,!``B!&("!0$""
MF8`L0`@"`00@`&``"021(X2*EU!@!0`````````&````!P````D`````````
M````````````````"@````P````.````$````!$````2````%````!<`````
M````&0``````````````&@```!T````>`````````"(````C````)```````
M```E````)@```"H`````````+```````````````+0```"X````O````,```
M```````T````-0`````````Y```````````````Z````/0```#X`````````
M/P```$````!"````1````$<`````````2@```$L```!,````30````````!.
M````````````````````````````````````3P```%``````````4@``````
M``!4````5P```%D`````````````````````````6@```%X`````````8```
M``````!A`````````&,```!D``````````````!F````9P```&D```!J````
M;0```%^6DQRC6N^0PHZ'_U?;DQP-.I<+TE$$A(%T@@UZ\$IK?4&.Q794/)3-
M/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`7@:DA_\!KS3HL4B=Y\[>
M1RW@IP(*STJN_^-'Q@$^?I9\Q@[@/>P_D`)M<X7%Q8D%D&&8[Q(!(_FDG;N3
M'$)%U>Q\[1$/4.X1XX?YG(%:FCL/NY63'$%-G7RGW:-K6>^7>3GRBQP,%.*>
M!#*EA:("]AG;S>.>^Z%L8.K3[P[(.4`?,F+;[;F-\0[I^\/"[-Z3'$HB??\+
MBA!7K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_+)@BU&BZXY)\(?_D#HJ8
MW<)N>FGZB]DU5Y.M!&(WX_#!0_+OR-^%($]7I)N6Q;F<0%`;?5\QN((-OMI7
M&[,!BV]V;^-PO-!+?9E"[J&>(L>H:PE#UB%B9`=^J9R;8M#Z@NPL]HMK?YI\
MT)\L_(?PEGSO"U'YD'6"#4-F2Q`%;++-/*TY#1?J6O&CX/M)XE?$&%>26E+]
MTN\/;L7?'WR0$.DMW_Y(+L6;MMZKRI_)U;)Q````````````````````````
M````````$0```"``````````````````````````+0```"``````````````
M````````````/````"``````````````````````````4````"``````````
M````````````````C`,``!(`````(4``````````````````3P(``!(`````
M($``````````````````R@(``!(```!@'T``````````````````Y@(``!(`
M``!@(D``````````````````@00``"``%P`PPD$`````````````````Y`$`
M`!(```"P(4``````````````````PP(``!(````@(D``````````````````
MU`$``!(`````'T``````````````````#04``!(`#0#<5D```````$``````
M````Z@,``!``&`!0PD$`````````````````?0(``!(```"P'T``````````
M````````J`(``!(```"0(D``````````````````P00``!$`%P!(PD$`````
M``@`````````*0,``!(```"P'D``````````````````*04``!(`#0"44D``
M`````,P#````````9@0``!(`#0`T1$```````#0!````````DP,``!(```#`
M'T``````````````````C@(``!(```!0($``````````````````.@,``!(`
M``#0'D``````````````````^0,``!``&`"HTD$`````````````````#P$`
M`!(```#P($``````````````````<@0``!(`#0#L2$```````*@)````````
MFP0``!(`#0!804```````-``````````1`0``!(````0(4``````````````
M````600``!(`#0`41$```````"``````````>`(``!(```"@'D``````````
M````````M0(``!(```!`($``````````````````K0$``!(```!`(4``````
M````````````%@,``!(```!0(4``````````````````I@,``"$`&`!PPD$`
M``````@`````````-P(``!(````P(D``````````````````/@(``!(```"`
M(D``````````````````V`(``!(```"`'D``````````````````UP,``!``
M%P!0PD$`````````````````O0(``!(```"@($``````````````````\P(`
M`!(```#@($``````````````````G@```!(`````(D``````````````````
M,0(``!(```!P($``````````````````7@,``!(```#0(4``````````````
M````5P(``!(````0(D``````````````````IP,``"$`&`!PPD$```````@`
M````````!`0``!``&`"HTD$`````````````````,P,``!$`&`!0PD$`````
M``@`````````$00``!(`#0"H5T````````0`````````N`$``!(```"0'T``
M````````````````A@$``!(```"`($``````````````````L00``!(`#0`P
M5T```````'@`````````[00``!(`#0"X1T```````#0!````````&P0``!(`
M#@"L5T``````````````````EP(``!(```!@($``````````````````A00`
M`!(`#0#0)$``````````````````V@0``!(`"P`8'D``````````````````
MO@```!(````P(4``````````````````T0(``!(```!P'D``````````````
M````"`,``!(```"`'T```````````````````@$``!$`&`!@PD$```````$`
M````````C`0``!$`#P#`5T````````0`````````W@,``!``&`!0PD$`````
M````````````90,``!(```"0(4``````````````````?0,``!(```!@'D``
M````````````````:@```!(```"`(4``````````````````'`$``!(```#`
M(4``````````````````V`0``!(`#0#40$```````#0`````````3P$``!(`
M``!`'T``````````````````#`0``!``&`"HTD$`````````````````X`0`
M`!(`#0`L0D```````.@!````````TP```!(```#P'D``````````````````
M9@(``!(````0'T``````````````````AP```!(```!P(D``````````````
M````'0(``!(````P($``````````````````Q@$``!(```#P(4``````````
M````````X0```!(```#@'T``````````````````\P```!(```!`(D``````
M````````````+0$``!$`&`!8PD$```````0`````````I0,``!$`&`!PPD$`
M``````@`````````>`$``!(```"@'T``````````````````WP(``!(```#0
M'T``````````````````^`,``!``&`"HTD$`````````````````_P0``!(`
M#0`P1T```````&@`````````(0,``!(```#@'D``````````````````KP``
M`!(````P'T``````````````````.`$``!(```#@(4``````````````````
M;P,``!(```"0'D``````````````````?P0``!``%P`PPD$`````````````
M````Q0,``!$`&`!HPD$```````@`````````,@0``!(`#0"81T```````"``
M`````````@(``!(```#P'T``````````````````[P$``!(````@($``````
M````````````H`,``!(`#0"P(D```````!0"````````2@,``!(```#0($``
M````````````````5`$``!(```!P(4``````````````````00,``!(```#`
M'D```````````````````0,``!(```!0'D``````````````````[0(``!(`
M```@(4``````````````````A0(``!(````@'T``````````````````^P$`
M`!(```!P'T``````````````````A0,``!(```"P($``````````````````
MRP0``!(`#0!H14```````,@!````````40,``!(```!0'T``````````````
M````60$``!(```"@(4``````````````````KP(``!(```"@(D``````````
M````````300``!(`#0!@5D```````'P`````````>````!(```#`($``````
M````````````E@$``!(```!0(D``````````````````(00``!(`#0`H0D``
M``````0`````````GP$``!(````0($``````````````````90$``!(```!@
M(4```````````````````&QI8G!E<FPN<V\N-2XQ.`!?251-7V1E<F5G:7-T
M97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA
M<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`
M4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T
M9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P
M=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E
M;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?
M7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D
M:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R
M=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I
M;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA
M:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H
M:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S
M<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R
M96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A
M=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN
M:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!'3$E"0U\R+C$W```````````````"``,``@`"``$````"````
M`0`!``(``@`!``(``0`!``(``@`"``$````!``$``@`!``(``@````(``@`#
M``,``@`!``(``@````,``@`#``(``0`"``$```````$``0`!``(``0`!````
M`@`"`````0`!``(``@```````0````$``0````(````#`````````````@``
M``(``0`!``(```````(``0`$``$```````$``@`"``(``@`"``(``@`"``$`
M`@````(``0```````0```````````````0`!`*\#```0````(````)>1E@8`
M``0`/P4````````!``$`#0(``!`````@````EY&6!@```P`_!0````````$`
M`0!<`@``$`````````"7D98&```"`#\%````````X+]!```````!!````@``
M````````````4,)!````````!```+P``````````````6,)!````````!```
M3@``````````````8,)!````````!```/```````````````:,)!````````
M!```60``````````````<,)!````````!```3P```````````````,!!````
M```"!```80``````````````",!!```````"!```0```````````````$,!!
M```````"!```.@``````````````&,!!```````"!```)0``````````````
M(,!!```````"!```5P``````````````*,!!```````"!```'@``````````
M````,,!!```````"!```$@``````````````.,!!```````"!```8```````
M````````0,!!```````"!```%P``````````````2,!!```````"!```5```
M````````````4,!!```````"!```1P``````````````6,!!```````"!```
M#```````````````8,!!```````"!```2```````````````:,!!```````"
M!```8P``````````````<,!!```````"!```50``````````````>,!!````
M```"!```1```````````````@,!!```````"!```9P``````````````B,!!
M```````"!```!P``````````````D,!!```````"!```9```````````````
MF,!!```````"!```.P``````````````H,!!```````"!```,0``````````
M````J,!!```````"!```4```````````````L,!!```````"!```#P``````
M````````N,!!```````"!```%0``````````````P,!!```````"!```40``
M````````````R,!!```````"!```3```````````````T,!!```````"!```
M6P``````````````V,!!```````"!```!@``````````````X,!!```````"
M!```;@``````````````Z,!!```````"!```7```````````````\,!!````
M```"!```2@``````````````^,!!```````"!```'P```````````````,%!
M```````"!```%@``````````````",%!```````"!```-@``````````````
M$,%!```````"!```*@``````````````&,%!```````"!```,@``````````
M````(,%!```````"!````@``````````````*,%!```````"!```)P``````
M````````,,%!```````"!```90``````````````.,%!```````"!```:P``
M````````````0,%!```````"!```7@``````````````2,%!```````"!```
M*```````````````4,%!```````"!```&0``````````````6,%!```````"
M!```!0``````````````8,%!```````"!```'```````````````:,%!````
M```"!```8@``````````````<,%!```````"!```.0``````````````>,%!
M```````"!```(```````````````@,%!```````"!```(0``````````````
MB,%!```````"!```;P``````````````D,%!```````"!```7P``````````
M````F,%!```````"!```00``````````````H,%!```````"!```/P``````
M````````J,%!```````"!```:```````````````L,%!```````"!```"@``
M````````````N,%!```````"!```0@``````````````P,%!```````"!```
M*P``````````````R,%!```````"!```5@``````````````T,%!```````"
M!```2P``````````````V,%!```````"!```*0``````````````X,%!````
M```"!```+```````````````Z,%!```````"!```"P``````````````\,%!
M```````"!```(P``````````````^,%!```````"!```30``````````````
M`,)!```````"!```;```````````````",)!```````"!```"```````````
M````$,)!```````"!```20``````````````&,)!```````"!```)```````
M````````(,)!```````"!```$```````````````*,)!```````"!```:0``
M````````````_7N_J?T#`)&^`0"4_7O!J,`#7]8`````\'N_J=```-`1_D?Y
M$.(_D2`"']8?(`/5'R`#U1\@`]70``#P$0)`^1`"`)$@`A_6T```\!$&0/D0
M(@"1(`(?UM```/`1"D#Y$$(`D2`"'];0``#P$0Y`^1!B`)$@`A_6T```\!$2
M0/D0@@"1(`(?UM```/`1%D#Y$*(`D2`"'];0``#P$1I`^1#"`)$@`A_6T```
M\!$>0/D0X@"1(`(?UM```/`1(D#Y$`(!D2`"'];0``#P$29`^1`B`9$@`A_6
MT```\!$J0/D00@&1(`(?UM```/`1+D#Y$&(!D2`"'];0``#P$3)`^1""`9$@
M`A_6T```\!$V0/D0H@&1(`(?UM```/`1.D#Y$,(!D2`"'];0``#P$3Y`^1#B
M`9$@`A_6T```\!%"0/D0`@*1(`(?UM```/`11D#Y$"("D2`"'];0``#P$4I`
M^1!"`I$@`A_6T```\!%.0/D08@*1(`(?UM```/`14D#Y$(("D2`"'];0``#P
M$59`^1"B`I$@`A_6T```\!%:0/D0P@*1(`(?UM```/`17D#Y$.("D2`"'];0
M``#P$6)`^1`"`Y$@`A_6T```\!%F0/D0(@.1(`(?UM```/`1:D#Y$$(#D2`"
M'];0``#0$6Y`^1!B`Y$@`A_6T```T!%R0/D0@@.1(`(?UM```-`1=D#Y$*(#
MD2`"'];0``#0$7I`^1#"`Y$@`A_6T```T!%^0/D0X@.1(`(?UM```-`1@D#Y
M$`($D2`"'];0``#0$89`^1`B!)$@`A_6T```T!&*0/D00@21(`(?UM```-`1
MCD#Y$&($D2`"'];0``#0$9)`^1""!)$@`A_6T```T!&60/D0H@21(`(?UM``
M`-`1FD#Y$,($D2`"'];0``#0$9Y`^1#B!)$@`A_6T```T!&B0/D0`@61(`(?
MUM```-`1ID#Y$"(%D2`"'];0``#0$:I`^1!"!9$@`A_6T```T!&N0/D08@61
M(`(?UM```-`1LD#Y$((%D2`"'];0``#0$;9`^1"B!9$@`A_6T```T!&Z0/D0
MP@61(`(?UM```-`1OD#Y$.(%D2`"'];0``#0$<)`^1`"!I$@`A_6T```T!'&
M0/D0(@:1(`(?UM```-`1RD#Y$$(&D2`"'];0``#0$<Y`^1!B!I$@`A_6T```
MT!'20/D0@@:1(`(?UM```-`1UD#Y$*(&D2`"'];0``#0$=I`^1#"!I$@`A_6
MT```T!'>0/D0X@:1(`(?UM```-`1XD#Y$`('D2`"'];0``#0$>9`^1`B!Y$@
M`A_6T```T!'J0/D00@>1(`(?UM```-`1[D#Y$&('D2`"'];0``#0$?)`^1""
M!Y$@`A_6T```T!'V0/D0H@>1(`(?UM```-`1^D#Y$,('D2`"'];0``#0$?Y`
M^1#B!Y$@`A_6T```T!$"0?D0`@B1(`(?UM```-`1!D'Y$"((D2`"'];0``#0
M$0I!^1!"")$@`A_6T```T!$.0?D08@B1(`(?UM```-`1$D'Y$(((D2`"'];0
M``#0$19!^1"B")$@`A_6_7NZJ?T#`)&@3P"YH2,`^:(?`/F@,P&1H0,!D:+C
M`)'S4P&I]1,`^7K__Y<!``"0(8`%D0```)````B1X@,!J@L-`)3```#0%(!)
M.=,``-!T`0`U.___E\(``/!"``Z10``2^$`-`+0&__^7TP``T&!:0KE#__^7
M%)0C.6!:0KE`__^7`OA3.>$#`*I"`!\R8%I"N2+X$SDZ__^7H4]`N0+X4SDA
M%``1(7Q`D^`#9YXA`&.>(2A@'@`+`%Q"```R`O@3.3`@8!X,"@!4(/!]TRC_
M_Y?C`P"JH"-`^<$``-`$`$#Y(0`)D60``/D$``#PA&`PD60$`/D$``#P)01`
M^82`,)'3``#PHD]`N6$"#I%D#`#YA`"`4B,`$?AE"`#Y)(`0N%\$`'&-`0!4
M1@@`4<8$`)'&\'W3`0"`T@0``8N%!$#Y9``!BR$@`)&%$`#Y/P`&ZT'__U1!
M$``1=0(.D67,(8L$`(#2H`)2^`$``-`A(`210@P`$:2`'_AA__^7]`,`*D`"
M`#1U`@Z1H`)2^-3^_Y<```#P`*`CD:%S`9%B!0"4P`$`M',"#I%@`E+XN/[_
MET?__Y?@`Q0J]1-`^?-30:G]>\:HP`-?UJ`"4OAT__^7]`,`*NS__Q>@@E'X
M8```M',,`)3P__\7````\`#`(9&A<P&13`4`E*""$?A`_?^T^/__%TK__Y<@
M`(!2>/[_EQ\@`]4```````#`0QT`@-(>`(#2_0,`D>4#`*KA`T#YXB,`D>8#
M`)&@``!8PP``6.0``%BR_O^7Z?[_E[`B0```````,%=```````"H5T``````
M`,```+``\$?Y0```M-O^_Q?``U_6`````,$``-#```#0(4`)D?U[OZD`0`F1
M(1P`D?T#`)$A``#+/S@`\6@``%3]>\&HP`-?UH$``%BA__^T(``_UOO__Q<`
M`````````,```-#!``#0`$`)D2%`"9$A``#+_7N_J2'\0Y/]`P"1(?Q!BR'\
M09-A``"U_7O!J,`#7]:B``!8HO__M$``/];[__\7'R`#U0``````````_7N^
MJ?T#`)'S"P#YTP``T&#B23F````UU/__ER``@%)@X@DY\PM`^?U[PJC``U_6
M_7N_J?T#`)'```"P`>A&^0!`-Y&!``"TP0``6$$``+0@`#_6_7O!J-;__Q<?
M(`/5``````````#_`PK1`^``D0K@`9'B`P"1881`^$)``)$D_&#3)=QXTXC<
M>-,I'&C3)OQ(TR?\:-.E''"2"!UPDH0<:-/&''B2I0`)J@0!!*KG''B2I0`&
MJH0`!ZHF?%C3I0`&JH'@0:I%`!_X08`?^'\`"NLA_?]4X:,!D>:C"9$E@%WX
M(@!`^22`6O@C@%GXH@`"RD(`!,I"``/*0_A_TV)\0JI"?$"2(@P`^2$@`)$_
M``;K8?[_5`H00/GD`T#Y`0!`^2,SC]("!$#Y"`A`^0D,0/E$`02+0U"K\HL`
M`XLDZ'O3`P$"BB<!(HI%A&+3A&Q!JN8'0/GG``.J9$$DBZ4(0JJE?$"2C``'
MBR,SC]*$?4"2!P$ABB8!!HNK``&*0U"K\L,``XMK`0>J)H1BTX?H>]/M"T#Y
MYVQ$JFL`"XO&"$&JQGQ`DFM!)XLG,X_28WU`D@T!#8NO`"2*C`$&BD=0J_*G
M`0>+[P$,JI"$8M-LZ'O3[@]`^>\`#XL$"D2JC&U#JBTSC]*'?$"2[$$LBTU0
MJ_*$?4"2S0$-B\\`(XIK`0>*I0$%B^\!"ZIPA&+3B^A[T^X30/FO``^+`PI#
MJFMM1*HM,X_297Q`DNM!*XM-4*OR8WU`DLT!#8OO`"2*C`$%BJ8!!HOO`0RJ
MD(1BTVSH>]/N%T#YSP`/BP0*1*J,;4.J+3./TH9\0)+L02R+35"K\H1]0)+-
M`0V+KP`CBFL!!HJG`0>+[P$+JG"$8M.+Z'O3[AM`^>\`#XL#"D.J:VU$JBTS
MC])G?$"2ZT$KBTU0J_)C?4"2S0$-B\\`)(J,`0>*I0$%B^\!#*J0A&+3;.A[
MT^X?0/FO``^+!`I$JHQM0ZHM,X_2A7Q`DNQ!+(M-4*ORA'U`DLT!#8OO`".*
M:P$%BJ8!!HOO`0NJ<(1BTXOH>]/N(T#YSP`/BP,*0ZIK;42J+3./TF9\0)+K
M02N+35"K\F-]0)+-`0V+KP`DBHP!!HJG`0>+[P$,JI"$8M-LZ'O3[B=`^>\`
M#XL$"D2JC&U#JBTSC]*'?$"2[$$LBTU0J_*$?4"2S0$-B\\`(XIK`0>*I0$%
MB^\!"ZIPA&+3B^A[T^XK0/FO``^+`PI#JFMM1*HM,X_297Q`DNM!*XM-4*OR
M8WU`DLT!#8OO`"2*C`$%BJ8!!HOO`0RJD(1BTVSH>]/N+T#YSP`/BP0*1*J,
M;4.J+3./TH9\0)+L02R+35"K\H1]0)+-`0V+KP`CBFL!!HJG`0>+[P$+JG"$
M8M.+Z'O3[C-`^>\`#XL#"D.J:VU$JBTSC])G?$"2ZT$KBTU0J_)C?4"2S0$-
MB\\`)(J,`0>*I0$%B^\!#*J0A&+3;.A[T^XW0/FO``^+!`I$JHQM0ZHM,X_2
MA7Q`DNQ!+(M-4*ORA'U`DLT!#8OO`".*:P$%BJ8!!HOO`0NJ<(1BTXOH>]/N
M.T#YSP`/BP,*0ZIK;42J+3./TF9\0)+K02N+35"K\F-]0)+-`0V+KP`DBHP!
M!HJG`0>+[P$,JI"$8M-LZ'O3[C]`^>\`#XL$"D2JC&U#JBTSC]*'?$"2[$$L
MBTU0J_*$?4"2S0$-B\\`(XIK`0>*I0$%B^\!"ZIPA&+3B^A[T^Y#0/FO``^+
M`PI#JFMM1*HM,X_297Q`DNM!*XM-4*OR8WU`DLT!#8OO`"2*C`$%BJ8!!HOO
M`0RJD(1BTVSH>]/N1T#YSP`/BP0*1*J,;4.J+3./TH9\0)+L02R+35"K\H1]
M0)+-`0V+KP`CBFL!!HJG`0>+[P$+JG"$8M.+Z'O3[DM`^>\`#XL#"D.J:VU$
MJBTSC])G?$"2ZT$KBTU0J_)C?4"2S0$-B]``)(J,`0>*$`(,JJ4!!8MLZ'O3
MC81BT^]/0/FD"42JI0`0BXQM0ZHM,X_2CGQ`DJQ`+(M-4*ORA7U`DO``(XKM
M`0V+:P$.B@L""ZJF`0:+K>A[T^]30/G&``N+K6U%JG"$8M,K=)W2`PI#JLU`
M+8LKVZWRIGU`DNL!"XMD``3*9P$'BX0`#$K+Z'O3[U=`^>P`!(MK;4:JIX1B
MTR1TG=+G"$6JBT$KBR3;K?)E?4"2[`$$B^\``\KM`0U*C`$.BZ3H>]/O6T#Y
MA&Q%JHP!#8LN=)W2S81BTZ8)1JJ,022++MNM\H1]0)+-``?*[@$.BZL!"TK#
M02.+CNA[T^]?0/EC``N+SFU$JJN$8M,M=)W2:PE%JFY`+HLMVZWRPWU`DNT!
M#8MO`0;*IT$GB^P!#$IMZ'O3[V-`^>P`#(NM;4.JAX1BTR5TG=+G"$2JC4$M
MBR7;K?*D?4"2Y0$%B^\`"\JF0":+[@$.2HSH>]/O9T#YS@`.BXQM1*IFA&+3
M)72=TL8(0ZK,02R+)=NM\H-]0)+.``?*Y0$%B\T!#4JK0"N+<.A[T^]K0/D0
M;D.J:P$-BX6$8M,N=)W2I0A$JFM!,(LNVZWR9'U`DNX!#HNO``;*QT$GB^P!
M#$J-Z'O3[V]`^>P`#(NM;42J9X1BTRYTG=+G"$.JC4$MBR[;K?*C?4"2[@$.
MB^\`!<K&02:+ZP$+2FSH>]/O<T#YRP`+BXQM0ZJ&A&+3+G2=TL8(1*IL02R+
M+MNM\H1]0)+N`0Z+SP`'RL5!)8OM`0U*B^A[T^]W0/FM``V+:VU$JF6$8M,N
M=)W2I0A#JJM!*XLNVZWR8WU`DNX!#HNO``;*QT$GB^P!#$IMZ'O3[WM`^>P`
M#(NM;4.JAX1BTRYTG=+G"$2JC4$MBR[;K?*D?4"2[@$.B^\`!<K&02:+ZP$+
M2HSH>]/O?T#YRP`+BXQM1*IFA&+3+G2=TL8(0ZIL02R++MNM\H-]0)+N`0Z+
MSP`'RL5!)8OM`0U*:^A[T^^#0/FM``V+:VU#JH6$8M,N=)W2I0A$JJM!*XLN
MVZWR9'U`DNX!#HNO``;*QT$GB^P!#$J-Z'O3[X=`^>P`#(NM;42J9X1BTRYT
MG=+G"$.JC4$MBR[;K?*C?4"2[@$.B^\`!<K&02:+ZP$+2FSH>]/OBT#YRP`+
MBXQM0ZJ&A&+3+G2=TL8(1*IL02R++MNM\H1]0)+N`0Z+SP`'RL5!)8OM`0U*
MB^A[T^^/0/FM``V+:VU$JF6$8M,N=)W2I0A#JJM!*XLNVZWR8WU`DNX!#HNO
M``;*QT$GB^P!#$IMZ'O3[Y-`^>P`#(NM;4.JAX1BTRYTG=+G"$2JC4$MBR[;
MK?*D?4"2[@$.B^\`!<K&02:+ZP$+2HSH>]/OET#YRP`+BXQM1*IFA&+3+G2=
MTL8(0ZIL02R++MNM\H-]0)+N`0Z+SP`'RL5!)8OM`0U*:^A[T^^;0/FM``V+
M:VU#JH6$8M,N=)W2I0A$JJM!*XLNVZWR9'U`DJT`!LKN`0Z+QT$GBZP!#$J.
MZ'O3[Y]`^<YM1*KL``R++72=TF>$8M/G"$.JC$$NBRW;K?*#?4"2[@`%RNT!
M#8NM02:+<.A[T\L!"TJ&A&+3Q@A$JNZC0/D$;D.JJP$+BXV;E]+/``>J:T$D
MBVWCL?)D?4"2S0$-BXP!#XK.``>*K4$EBX_H>].,`0XJ981BTZ4(0ZKNIT#Y
MXVU$JJP!#(N-FY?2KP`&JHQ!(XMMX['R@WU`DLT!#8MK`0^*K@`&BFL!#BIO
MZ'O3IT$GBXV$8M.D"42J[JM`^><`"XN-FY?2ZVU#JNM`*XN/``6J;>.Q\F=]
M0)+-`0V+C`$/BHX`!8J,`0XJ[^A[TZ9!)HMMA&+3HPE#JNZO0/G&``R+C9N7
MTNQM1ZK,0"R+;P`$JFWCL?*&?4"2S0$-BVL!#XIN``2*:P$.*L_H>].E026+
M[81BTZ<)1ZKNLT#YI0`+BXV;E]+K;4:JJT`KB^\``ZIMX['R97U`DLT!#8N,
M`0^*[@`#BHP!#BJOZ'O3I$$DB\V$8M.F"4:J[K=`^80`#(N-FY?2[&U%JHQ`
M+(O/``>J;>.Q\H1]0)+-`0V+:P$/BLX`!XIK`0XJC^A[TZ-!(XNMA&+3I0E%
MJNZ[0/EC``N+C9N7TNMM1*IK0"N+KP`&JFWCL?)C?4"2S0$-BXP!#XJN``:*
MC`$.*G#H>].G02>+C81BTZ0)1*KOOT#YYP`,BXV;E](,;D.JC@`%JNQ`+(MM
MX['RAWU`DNT!#8MK`0Z*C@`%BFL!#BKOZ'O3ID$FBVV$8M.C"4.J[L-`^<8`
M"XN-FY?2ZVU'JLM`*XMO``2J;>.Q\F9]0)+-`0V+C`$/BFX`!(J,`0XJS^A[
MTZ5!)8OMA&+3IPE'JN['0/FE``R+C9N7TNQM1JJL0"R+[P`#JFWCL?*%?4"2
MS0$-BVL!#XKN``.*:P$.*J_H>].D022+S81BTZ8)1JKNRT#YA``+BXV;E]+K
M;46JBT`KB\\`!ZIMX['R9'U`DLT!#8N,`0^*S@`'BHP!#BJ/Z'O3HT$CBZV$
M8M.E"46J[L]`^6,`#(N-FY?2[&U$JFQ`+(NO``:J;>.Q\H-]0)+-`0V+:P$/
MBJX`!HIK`0XJ;^A[TZ=!)XN-A&+3I`E$JN[30/GG``N+C9N7TNMM0ZKK0"N+
MCP`%JFWCL?)G?4"2S0$-BXP!#XJ.``6*C`$.*N_H>].F02:+;81BTZ,)0ZKN
MUT#YQ@`,BXV;E]+L;4>JS$`LBV\`!*IMX['RAGU`DLT!#8MK`0^*;@`$BFL!
M#BK/Z'O3I4$EB^V$8M.G"4>J[MM`^:4`"XN-FY?2ZVU&JJM`*XOO``.J;>.Q
M\F5]0)+-`0V+C`$/BNX``XJ,`0XJK^A[TZ1!)(O-A&+3I@E&JN[?0/F$``R+
MC9N7TNQM1:J,0"R+SP`'JFWCL?*$?4"2S0$-BVL!#XK.``>*:P$.*H_H>].C
M02.+K81BTZ4)1:KNXT#Y8P`+BXV;E]+K;42J:T`KBZ\`!JIMX['R8WU`DLT!
M#8N,`0^*K@`&BHP!#BJG02>+CH1BTVWH>]/$"42JYP`,B^[G0/FM;4.JC)N7
MTH\`!:KM0"V+;..Q\J=]0)+,`0R+:P$/BHX`!8IK`0XJ[^A[TXQ!)HMFA&+3
MPPA#JHP!"XOFZT#YZVU'JHZ;E])O``2JC$$KBV[CL?*+?4"2S@`.BZT!#XIF
M``2*K0$&*F_I>]/.026+YH1BT\8(1ZKE[T#YYVU+JLX!#8N-FY?2SP`#JLY!
M)XMMX['RQWU`DJT`#8N,`0^*Q0`#BHP!!2KOZ'O3K4$DBV2%8M/E;4>JBPA+
MJJT!#(OD\T#YS#J8TJU!)8M,3+GRI7U`DHP`#(NOZ'O39`$&RHQ!(XOCA&+3
M9PA'JHX`#DKC]T#YY&U%JL\ZF-*,`0Z+3TRY\F\`#XN,022+XP`+RH1]0))M
M``U*YD$FBX[H>]/&``V+K81BT\-M1*JE"46JSCJ8TNW[0/G&0".+3DRY\L-\
M0)*N`0Z+K0`'RLM!*XNL`0Q*;NA[TVP!#(O.;4.JCD$NBXN$8M/L_T#YS3J8
MTFL)1*I-3+GRQ'U`DHT!#8ML`07*A@$&2J=!)XN-Z'O3YP`&BZUM1*KM0"V+
M9H1BT^<#0?G,.IC2Q@A#JDQ,N?*C?4"2[``,B\<`"\KN``Y*A4$EBVSH>].E
M``Z+C&U#JJQ`+(N'A&+3Y0=!^<\ZF-+G"$2J3TRY\H1]0)*O``^+Y0`&RJT`
M#4KK02N+C^A[T^]M1*IK`0V+981BT^T+0?G..IC2I0A#JFM!+XM.3+GR8WU`
MDJ\`!\JM`0Z+ID$FB^P!#$IMZ'O3S``,BZUM0ZJ-02V+AH1BT^P/0?G..IC2
MQ@A$JDY,N?*D?4"2SP`%RHP!#HN'02>+ZP$+2HSH>]/K``N+C&U$JFQ!+(MG
MA&+3ZQ-!^<XZF-+G"$.J3DRY\H-]0)+O``;*:P$.BV5!)8OM`0U*:^A[TZT`
M#8MK;4.JJT$KBX6$8M/M%T'YSCJ8TJ4(1*I.3+GR9'U`DJ\`!\JM`0Z+ID$F
MB^P!#$J-Z'O3S``,BZUM1*J-02V+9H1BT^P;0?G..IC2Q@A#JDY,N?*C?4"2
MSP`%RHP!#HN'02>+ZP$+2FSH>]/K``N+C&U#JFQ!+(N'A&+3ZQ]!^<XZF-+G
M"$2J3DRY\H1]0)+O``;*:P$.BV5!)8OM`0U*B^A[TZT`#8MK;42JJT$KBV6$
M8M/M(T'YSCJ8TJ4(0ZI.3+GR8WU`DJ\`!\JM`0Z+ID$FB^P!#$IMZ'O3S``,
MBZUM0ZJ-02V+AH1BT^PG0?G..IC2Q@A$JDY,N?*D?4"2SP`%RHP!#HN'02>+
MZP$+2HSH>]/K``N+C&U$JFQ!+(MGA&+3ZRM!^<XZF-+G"$.J3DRY\H-]0)+O
M``;*:P$.BV5!)8OM`0U*:^A[TZT`#8MK;4.JJT$KBX6$8M/M+T'YSCJ8TJ4(
M1*I.3+GR9'U`DJ\`!\JM`0Z+ID$FB^P!#$J-Z'O3S``,BZUM1*J-02V+9H1B
MT^PS0?G..IC2Q@A#JDY,N?*C?4"2SP`%RHP!#HN'02>+ZP$+2FSH>]/K``N+
MC&U#JFQ!+(N'A&+3ZS=!^<XZF-+G"$2J3DRY\H1]0)+O``;*:P$.BV5!)8OM
M`0U*B^A[TZT`#8MK;42JJT$KBV6$8M/M.T'YSCJ8TJ4(0ZI.3+GR8WU`DJX!
M#HNM``?*QD$FBV_H>].L`0Q*S``,B^9M0ZK&``P+CH1BT^P_0?G-.IC2Q`E$
MJDU,N?*-`0V+C``%RJ=!)XN+`0M*S^A[T^L`"XMNA&+3YVU&JL,)0ZKG``L+
MX0`!"\(``@MC``@+A``)"Z4`"@L!``#Y_P,*D0($`/D#"`#Y!`P`^040`/G`
M`U_6_7N\J?T#`)'U6P*I]V,#J?-3`:GV`P"J^`,!JN`"`+3```"P%SA!^7<%
M`+3``D`Y'_0`<<$"`%05`(!2\P)`^;,!`+2U?D"3]`,7JN`#$ZKA`Q:JX@,5
MJF#Y_Y>````U8FIU.%_T`'$@`@!4DXY`^//^_[7@`Q.J\U-!J?5;0JGW8T.I
M_7O$J,`#7]9@_?\T]0,6JJ`>0#@?]`!Q0```5*#__S6U`A9+Y?__%Y0"%\N4
M_D.3%`,`N:`&`)%@`@"+]5M"J?-30:GW8T.I_7O$J,`#7];@`Q>JZ/__%_U[
MO:G]`P"1\U,!J?,#`*K4``"PX`,3JJ&S`)'"__^7``(`M*0O@+F".D'YA/!]
MTT$`!(LC!$#Y0V@D^,/^_[0A(`"1(@1`^2(``/FB__^UX`,3JJ&S`)&S__^7
M0/[_M?-30:G]>\.HP`-?UOU[NJG]`P"1\U,!J?5;`JGW8P.I^6L$J?,#`:HA
M`$`Y]0,`JC_T`'%S%I.:X`,3JLSX_Y?V`P"JH7,!D>`#%:J>__^7]`,`J@`'
M`+3%^/^7'T`VZ^(%`%2T7T"YUP``L*`"0#D?]`!Q@`H`5&`*`#3B`Q6J`@``
M%($``#1!'$`X/_0`<:'__U1"`!5+P`H`$?@Z0?D```(+E'Y]T^WX_Y<`:S3X
M0`D`M.`Z0?FA7T"YH@)`.0%X8?B@!@"1(@``.>(``#1?]`!QH```5`(40#@B
M'``X7_0`<8+__S6@!X!2(@0`D2```#E@%D`X0!0`.,#__S4``(!2\U-!J?5;
M0JGW8T.I^6M$J?U[QJC``U_6`0"`TF)J83B":B$X(00`D:+__S7T__\7UP``
ML/@Z0?D"`T#Y8@0`M.(#&*I#C$#XE`8`$</__[6!"@`1(7Q]D\(``+!"``J1
M0P!`N6,!`#3@`QBJ[_C_E^`Z`?D``P"TF7Y`D_H#`*HY!P"17WLY^+1?`+FW
M__\7X`,!JB$`@%)!``"YK_C_E_H#`*J``0"TF7Y`D^$#&*HB\WW39?C_E_HZ
M`?GQ__\7`@"`4K3__Q<!`H#2]`,"*N+__Q<``(`2RO__%_U[M*G]`P"1\U,!
MJ?5;`JGW&P#Y\P,`JF```+0!`$`YP0``-?-30:GU6T*I]QM`^?U[S*C``U_6
M;?C_E_0#`*H@__^T%P``T/?"'Y'@`Q2J$_G_E^$#`*HU3`"1X`,3JN$$`+0B
M3$`Y7[@`<:`%`%1'^/^7]@,`JN`#%:I$^/^7```6"P`(`!$`?$"3?/C_E^,#
M%ZKD`Q.JY0,5JB$`@%("`("2]@,`JCWX_Y?A`Q:JH@,!D0``@%)!^/^7'P0`
M,>`#%JJ@``!4H5-`N2$,%!(_$$!Q0`,`5#'Y_Y?@`Q:JY_C_E^`#%*KM^/^7
MX0,`JC5,`)'@`Q.J8?O_M>`#%*J7^/^7X`,3JLGX_Y?S4T&I]5M"J?<;0/G]
M>\RHP`-?UB)00#E?N`!Q(OG_-"'Z_U0A5$`YP?C_-,[__Q>Q__^7Y___%_U[
MO:G]`P"1\U,!J=,``+!@6D*Y]1,`^7CX_Y<!8$#Y8%I"N30$0/ET^/^7`71"
M.6!:0KDU&``2</C_EP`$0/D`0$!Y`2`94Z$"`2J!!@!Y8%I"N6GX_Y<!8$#Y
M8%I"N30$0/EE^/^7`0``T`(`@-(A0#"1D?C_EX`6`/E@6D*Y7OC_EP%@0/E@
M6D*Y-`1`^5KX_Y<!;$/Y8%I"N8$:`/E6^/^7`6!`^6!:0KDT!$#Y4OC_EP#D
M0/F``P"T8%I"N4[X_Y<`Y$#Y`51`^6!:0KF!'@#Y2?C_EP%@0/E@6D*Y(01`
M^3\@`/E$^/^7`6!`^6!:0KDA!$#Y/Q``^3_X_Y<!8$#Y8%I"N3,$0/D[^/^7
M`+!!^6`F`/GS4T&I]1-`^?U[PZC``U_6X0,`JNC__Q?]>[ZI_0,`D?-3`:G3
M``"P]`,`JF!:0KDL^/^7`H`'D>$#%*H``(!2</C_EZ```#0``(!2\U-!J?U[
MPJC``U_68%I"N2'X_Y<`\$&Y``P4$A\00''@``!48%I"N1OX_Y<`\$&Y``P4
M$A\H0'$A_O]4X`,4JD$`@%(T^/^7'P`?:^`7GQKS4T&I_7O"J,`#7];_!T#1
M_T,`T?U[O:G]`P"1\U,!J=0``)#U6P*I@S9!^?4#`*H```"P]@,!J@#@'Y&A
MXP"1XO^!TJ,?"/FC]_^7'P`?:\T#`%0#!`!1<WQ`DZ+C`)%!:',X`0,`-!-\
M0).@XP"1X06`4N(#$ZIO^/^78`(`M,```)``6$*Y[_?_E^$#%:JBXP"1XP,3
MJF_X_Y>A'TCY@#9!^3\``.OA`0!4\U-!J?5;0JG]>\.H_T,`D?\'0)'``U_6
M0_W_-<```)``6$*YW??_E^$#%:KB`Q:JMO?_E^___Q?D]_^7_7N_J?T#`)'`
M``"0`%A"N=/W_Y<!``"PXO__L`,``+#]>\&H(2`@D4(`/)%CH""1#_C_%_U[
MOJG]`P"1\PL`^=,``)!@6D*YQ??_E^W__Y=@6D*YPO?_EP,``+!C0#"1\PM`
M^0$``+`"``"P_7O"J"'@()%"4`J1Y`,#J@4`@%(;^/\7_PM`T?^#`-']>[VI
M_0,`D?43`/G5``"0H#9!^?-3`:F@)Q#Y>??_EP,``+`%``"PY`,`*B$`@%*@
MXP"1(@""TF-`(9&E@"&1//?_E\`#^#<!"(+2H.,`D2$`'8L"`(+20O?_E_,#
M`*KS`O@W8`8`$0!\0)-I]_^7]`,`J@`!`+1S?D"3`0B"TB$`'8OB`Q.J&O?_
ME^`#%*J?:C,XHB=0^:$V0?E?``'K(0$`5/-30:GU$T#Y_7O#J/^#`)'_"T"1
MP`-?U@``@-+U__\7C_?_E\S__Q?_!T#1_T,`T?U[NJG]`P"1^RL`^=L``)#U
M6P*I8C=!^?4#`*H```"P\U,!J0#`(9'S`P&JH9,!D?=C`ZGY:P2IHC<(^=K]
M_Y?T`P"JX06`4N`#%:K4]_^78`(`M````+```"*1X0,5JB/^_Y?@`Q6JHC=(
M^6$W0?E?``'K00L`5/-30:GU6T*I]V-#J?EK1*G[*T#Y_7O&J/]#`)'_!T"1
MP`-?UN`#%:KK]O^7%@``L/@#`"K!0B*1X`,3JN+V_Y?S`P"JP/S_M!<``+`:
M``"P&0``L/>B(9%:8R*1.8,BD6("0#E?`!]K<Q*7FK0``+3@`Q2JX0,3JG?W
M_Y<@!0`TX`,3JM3V_Y<"?$"30@0`T><#`*I@:F(X8@("BQ^\`''!``!47P``
M.4C\7SCG!`!1'[T`<8#__U3G!``1YP`8"__\/W',^/]4(0"`4@(`@M+D`Q.J
MXP,:JN4#&:KF`Q6JH*,!D<#V_Y?3``"08%I"N27W_Y<"@`>1H:,!D0``@%+!
M]O^7X```-6!:0KD>]_^7`/!!N0`,%!(?($!QX```5```@-+!0B*1I_;_E_,#
M`*J`^?^UJO__%Z"C`9$A`(!2,??_E^#^_S4```"PH:,!D0``(I'(_?^7H*,!
MD<;V_Y>D__\7%/?_EP$`0#G!```T`@0`D3^\`'$`$(*:011`.*'__S7``U_6
M_7N^J?T#`)'S4P&I\P,`JD`#`+0!`$`Y`0,`-(SV_Y<`!`#18@(`BW\"`NNB
M!`!48&I@.!^\`'&@``!4'@``%$``0#D?O`!Q80,`5$($`-%?`!/K8?__5$``
M0#D?O`!QP```5/-30:D```"P_7O"J`"`(I&>]O\70`"`TK#V_Y?A`P"J``4`
MM````+``H"&1`@!`>>`#`:HB``!Y\U-!J?U[PJC``U_60`!`.1^\`'&```!4
M0@0`T7\"`NMC__]47P`3ZZ$``%3D__\70`!`.1^\`'&!``!40@0`T7\"`NMC
M__]40@`3RT`(`)$?!$#QJ`$`5-0``)"4`@J1E"(`D>$#$ZK@`Q2J0@0`D0,`
M@M*/]O^7X`,4JO-30:G]>\*HP`-?U@``@-+S4T&I_7O"J,`#7];]>[BI_0,`
MD0```+``(!^1\U,!J=,``)`$%$"I`@Q!J0%`0'EF-D'Y````L`"@(I&F/P#Y
MI!<%J:(/!JFAXP!Y]5L"J?<;`/E!_?^7````L`#@(I$^_?^7````L```(Y$[
M_?^7````L`!`(Y$X_?^7%```L(!B(Y$U_?^7````L`"@(Y$R_?^7%0``L*#"
M(9$O_?^7%P``L.#B(Y$6``"P*_W_E]8B))'@`Q:J*/W_EP```+``8"21)?W_
MEP```+```"*1(OW_EP```+``H"21'_W_EP```+``X"21'/W_EP```+"A,P&1
M`"`ED>'\_Y?A`P"J8```M.`#%JHO_?^7````L*$S`9$`@"61V?S_E^$#`*J`
M``"T````L`#@)9$F_?^7````L*$S`9$`(":1T/S_E^$#`*H``@"TH,(AD1[]
M_Y<!``"P(0`GD8!B(Y$:_?^7H3]`^6`V0?D_``#K(0,`5/-30:GU6T*I]QM`
M^?U[R*C``U_6````L*$S`9$`8":1N_S_E^$#`*J```"TX.(CD0G]_Y?K__\7
M`0``L*"'`9$AP":10@&`TB?V_Y>@_/\UX.(CD:&O`9'__/^7X?__%TWV_Y?]
M>[VI_0,`D?,+`/G3``"08`()D0``0+D?!``Q@```5/,+0/G]>\.HP`-?U@``
M`+``X".1H;,`D9S\_Y?```"T`0!`.0``@%)A```T/\``<>`'GQIS`@F18`(`
MN?,+0/G]>\.HP`-?UOU[OZG]`P"1S/7_EUOV_Y=```"T``!`^?U[P:C``U_6
M_7NWJ?T#`)'W8P.I]P,`J@```+``@">1H#<`^0```+``H">1H#L`^0```+``
MP">1]5L"J:`_`/D6``"P%0``L````+#60B>1M2(GD0`@*)$#``"P!0``L/-3
M`:GY:P2IMB\`^;4S`/F@0P#YOT<`^;-C`9%Y8"*1N$`BD0<``!2*]O^7``,`
MM',B`)$5`@"T]@,5JG4&0/FA4P&1X`,6JF#\_Y?T`P"JX0,7JF```+0"`$`Y
M8O[_->`#%JKA`Q>JJOS_EW,B`)%5_O^U\U-!J?5;0JGW8T.I^6M$J?U[R:C`
M`U_6X`,7JGCU_Y?Z`P"JX`,4JG7U_Y=``P"+``@`D:[U_Y<"`("2XP,9JN0#
M%ZKE`QBJY@,4JB$`@%+Z`P"J;O7_E^`#%JKA`QJJC_S_E];__Q?_(T#1_T,%
MT?U[NJG]`P"1^6L$J1D``+`CXR61HUL`^0,``+#W8P.I8\`HD=<``)#D-D'Y
MHU\`^0,``+#U6P*I\U,!J?MS!:FG(T"18^`HD>34`/FC8P#Y%0``L`0``+`#
M``"PHF(HD82@*)%C`"F1I$,`^:-G`/FB3P#Y&```L`0``+`#``"P`@``L(2@
M(9%C("F10D`ID?]#`-'V`P"JH?,!D0##(9&D1P#YOTL`^:-K`/F_;P#YHE,`
M^;]7`/D+_/^7\P,`JF```+0!`$`Y`1\`-7;__Y?T`P"J(!\`M.`#%*HL]?^7
M`/A_TP`$`)%E]?^7A`)`.?H#`*H```"P\P,:JA6`*9$D`0`TX`,3JB$`@%("
M`("2XP,5JB+U_Y>$'D`X<PH`D23__S6TPP*1(.,ED0,``!2`CD#XH`$`M*'S
M`9'J^_^7\P,`JF#__[0!`$`Y(?__-$G]_Y?@_O\TX`,3JC3U_Y?D`P"J@`(`
MM;-#0/G3"0"T8`)`.30`@%*U`P*1X```-4D``!2SVG3X\P@`M&$"0#F4!@`1
M@0@`-.`#$ZHV_?^7(/__-.`#$ZHA]?^7Y`,`JJ#^_[3@`P2JI#,`^?3T_Y?T
M`P"JX`,:JO'T_Y<``!0+%!`0$91^0)/@`Q2J*/7_EZ0S0/D9``"P`P``L`8`
M`+`A`(!2`@"`DF.@*9$E@R*1QN`ID><#&JKU`P"JY/3_E^`#%:H!.(!2Y?7_
MEQ\$`#%@!`!4TP``D&!:0KE$]?^7`H`'D>$#%:H``(!2B/7_ER`%`#3```"0
M`"A!^<,"0/D"``"P(0"`4D(@+)'D`Q6J8_7_EP``@-*A(T"1(M1`^>$V0?E?
M``'KX3@`5+\#`)'S4T&I]5M"J?=C0ZGY:T2I^W-%J?U[QJC_0P61_R-`D<`#
M7]8$`(#2P___%[CU_Y<%`$"YOT0`<6#[_U3```"0`"A!^<,"0/D"``"P(0"`
M4D(`*I'D`Q6J1?7_EP``@-+B__\78%I"N17U_Y<`\$&Y``P4$A\00'%A^O]4
M8%I"N0_U_Y<:^$&YM?3_EU\#`&NA^?]48%I"N0GU_Y<`\$&Y`"``$A\`!W'A
M^/]4X`,4JM/T_Y?S`P"J````L`"@)Y&A\P&1:/O_EX`R`+34`D#YM_3_E^$#
M`*K@`Q2J=_W_E_0#`*J@,0"TX`,4JHCT_Y<?#`!Q^@,`JNT!`%0`?$"3`!``
MT0$``+"``@"+(0`KD1_U_Y<``0`U7Q,`<>`G`%1:$P!1FL(ZBT#S7S@?O`!Q
M0"<`5*+^_Y?A`P`JP```->`#%*I>]?^7H&\`N>`#`"K`"0`U`0``L````+`A
M`">1`.`CD9+[_Y>A]/^7%@``L-9",)$Y@R*1`P``L.8#`"HA`(!2X`,3J@(`
M@))C@"N1Y`,5JN4#&:KG`Q:J&@``L%_T_Y<4`(!26L,KD1$``!17]?^7``!`
MN1]$`'%!`@!4B_3_EY0&`!'F`P`J]@,`^>`#$ZHA`(!2`@"`DN,#&JKD`Q6J
MY0,9JN<#%"I,]/^7X`,3J@$X@%)-]?^7'P0`,8#]_U3@`Q6J_?3_E^$#$ZH`
MPR&19OO_E^`#$ZJ*_O^7X`,3JG'__Q>'_O^7X`,3JE_T_Y=M__\7H&(HD3,`
M@%*U8P*1!```%*#:<_AS!@`10`$`M*'S`9$#^_^78/__M`$`0#DA__\T4?3_
ME_0#`*K`_O^T^?[_%Q0``+"@`8#2E((HD?G^_Q<A`H"20@"`4G_T_Y>@;T"Y
MH:,&D<(`@-+_]/^7H*-&.8```#6@IT8Y'PP!<0`?`%0!`(#2H&]`N>(#`2IR
M]/^7)&"$TB-QE=+"GYO2P8Z*T@`^G-*DZ*SRH_F]\D(7L_)!!J+R0'JX\K2C
M!)&DEP#YHYL`^:*?`/FAHP#YH*<`^;^K`/F_KP#YOZ,!N9KB`)&@;T"YH:,&
MD0(`D-+>]/^7'P`?:_8#`*K\`P`J[0@`5(`60/G"?D"3`0P"BR%\0)(?``'K
M@!I`^4D``%0`!`"1`G1"BX!Z0+F!%@#Y@AH`^4`5`#0'"(!2_```2]\"'&O<
MTIP:@,(@BYM_0),`X`"1H:,&D>(#&ZK3\_^7@'I`N8`#``N`>@"Y'P`!<:'[
M_U2AHP:1X`,4JMP"'$L[`!N+P?7_EY__`'&-%`!4G`,!48)_!E/V`P(JU@8`
MD:)K`+EV&Q:+:"=`J68?0:EB#T*I9!=#J>`#%*I()P"I1A\!J4(/`JE$%P.I
M>P,!D:[U_Y=_`Q;K@?[_5*-K0+F<&P-+X0,6JH)_0),#"8#2X`,:JNWS_Y>@
M;T"YH:,&D0(`D-*<>@"YF/3_EQ\`'VOV`P"J_`,`*FSW_U2@;T"Y*O3_E[2K
M0/FEHP21@")#TP$$`!&BP""+XP^`$D/@`#D_X`!QMJ]`^>P.`%3B!H!2HZ,$
MD4(``$M@P"&+`.``D0$`@%)"?$"3\//_E\;^6-/%_E#3Q/Y(TX/^6-."_E#3
M@?Y(TZ"C!)&F8P8YI6<&.:1K!CFV;P8YHW,&.:)W!CFA>P8YM'\&.7CU_Y>F
MET#YI9M`^:.?0/FBHT#YH:=`^=K\4-/6_$C3Q'Q8T[+\6-.Q_%#3L/Q(TV_\
M6--N_%#3;?Q(TTS\6--+_%#32OQ(TRG\6-,H_%#3)_Q(T[3C`Y$```"0NH<#
M.;:+`SFD@P,YIH\#.;*3`SFQEP,YL)L#.:6?`SFOHP,YKJ<#.:VK`SFCKP,Y
MK+,#.:NW`SFJNP,YHK\#.:G#`SFHQP,YI\L#.:'/`SFVAP.1FZ(`D1J`*9$"
M```4Q!9`..`#%*HA`(!2`@"`DN,#&JI<\_^7E`H`D9\"&^L!__]4`P``D`<`
M`)`"`("28T`KD>0#%:HE@R*1IN,#D>=`,)$A`(!2X`,3JK^#!#E-\_^7X`,5
MJ@/T_Y?A`Q.J`,,AD6SZ_Y?@`Q.JD/W_E^`#$ZIW_O\7NZ,&D6K__Q?6!D#Y
MUMC_M.`#%JHZ\_^7'PP`\4G8_U0`$`#1`0``D,`"`(LA("N1T_/_EQ\`'VN4
M$I::NO[_%_8#&ZIQ__\7X@>`4D(``$N@P"&+0GQ`DP$`@%(`X`"1>_/_EZ"C
M!)$1]?^7H(,%D1]\`*D??`&I'WP"J;_+`/F$__\7H*M&.1\$`7'AX/]4H*]&
M.1\,`7&!X/]4H+-&.1\@`7$AX/]4H+=&.1\4`7'!W_]4H&]`N4(`@%(A!X"2
M;_/_EZ!O0+FAHP:1(@6`TN_S_Y<#``"0!P``D.`#$ZHA`(!2`@"`DF-`*Y'D
M`Q6J)8,BD::C!I'G0#"1!//_E[W^_Q=V\_^7U`)`^7/^_Q?]>[BI_0,`D?EK
M!*FZ``#P0%M"N?-3`:GU6P*I]V,#J?LK`/E>\_^7(0"`4@%D`CD```"0H?,!
MD0!@(Y'"^?^7@```M`$`0#D_Q`!QH!``5*'\_Y=`6T*YVP``D%#S_Y<!``"0
M(8`MD2(`@%)C`8!27_/_EZ`&`+1V`PZ1P8)0N``(0/D_!`!Q&11`^>T%`%05
M`8#2$P"`4EAC"9$+```400A`^>`#%ZIQ\_^70`0`-7,&`!'`@E"X8@8`$1\`
M`FNU(@"1S0,`5``#0+DT\_^7X0,9JN(#$RH#`(!2H//_E_0#`*J``@"T`@!`
M^0"`@%)$#$"Y``2@<L,"4?B````*'P`0<7=H=?C`_/]4``-`N2/S_Y>!`D#Y
M`@"`TD,`@%(+\_^7X0,`JN`#%ZI0\_^7`/S_-&`##I$`@%"X`00`43\`$VM`
M"0!40%M"N;0``/`3\_^7`0``D"&@+9$B`(!2@P"`4B+S_Y?S`P"J@`$`M(!:
M0KD*\_^780I`^0(``)`A`$#Y0L`MD>'R_Y=@"D#Y``!`^0`,0+E@"+`W0%M"
MN;0``/#^\O^7`0``D"'@+9$B`(!2@P"`4@WS_Y?S`P"JP`$`M````)```"*1
MH?,!D5WY_Y?B`P"J@%I"N2(+`+2B-P#Y[O+_EV$*0/FB-T#Y(0!`^<;R_Y=`
M6T*Y=0,.D>?R_Y<?9`(Y````D*'S`9$`P"&13/G_EZ""$?CT`P"JX`0`M`$X
M@%)Y\_^7'T0`<>,#`"J```!4``0`$1\$`'&H"P!4\U-!J?5;0JGW8T.I^6M$
MJ?LK0/G]>\BHP`-?U@`$0#F`[_\T>O__%Q\$`''-]O]4,P"`4E1C"9%U`PZ1
M@`)`N7,&`!'%\O^7X0,9JG/R_Y>@@E"X'P`3:RS__U2J__\7@%I"N;WR_Y=A
M"D#Y(0!`^1;S_Y>Y__\7H`)1^.;\_Y>@@A'X``<`M&$*0/D`@(!2(0!`^0`$
MH'(B#$"Y0```"A\`$''A!`!4(`A`^7L##I%T`U'XX0,4JM#R_Y=A"D#Y`H"`
M4B0`0/D"!*!RA0Q`N?4#`"JB``(*7P`0<90"0/GA`0!4@@A`^0```)``H"Z1
MX0,4JN,#%2K8\O^7E_+_EV$##I%@"D#Y(0!1^```0/DA`$#Y@_K_EZ?__Q=`
M6T*YCO+_EV$*0/D"`(#2(0!`^4,`@%)U\O^7X@,`JNO__Q>@``#P`%A"N83R
M_Y=A"D#YX@,4JB$`0/E#`(!2:_+_E]/__Q<```"0```ND;OR_Y>@`E'XX@,4
MJ@$`0/D```"0`$`OD;7R_Y?]>[ZI_0,`D?-3`:GT`P"J<?O_EP$`0#GS`P"J
MP0``-`($`)$_O`!Q<Q*"FD$40#BA__\U)_S_ET`!`#0T`0"T@`)`.>```#0!
M``"0X`,3JB'@*9'K\O^7?P(`ZX```%3S4T&I_7O"J,`#7];@`Q2J\U-!J?U[
MPJB'^?\7_7N^J?T#`)'S"P#YLP``\&!:0KE0\O^7`0"`$D;R_Y=@6D*Y3/+_
ME^'__]#S"T#Y_7O"J"'@.)$"`(#2UO+_%Z0``/"#X`B10P``M(,<0?GY\?\7
M_7N\J?T#`)'S4P&I]V,#J;0``-"X``#0&`,WD90B-Y&4`AC+E/Y#D_5;`JGW
M`P`J]@,!JO4#`JH3`(#2J_'_ES0!`+0#>W/XX`,7*N$#%JKB`Q6J8``_UG,&
M`)%_`A3K(?__5/-30:GU6T*I]V-#J?U[Q*C``U_6P`-?UOU[OZG]`P"1_7O!
MJ,`#7]8``````0`"``````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@(```````````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R``````!P97)L>'-I+F,`````````26YT97)N
M86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,``````&5X90``````+@``
M``````!005)?5$5-4```````````4$%27U!23T=.04U%`````#H`````````
M)7,E<R5S```O`````````%!%4DPU3$E"``````````!015),3$E"`%!%4DPU
M3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1```````4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#
M2$4`````````4$%27T%21T,``````````%!!4E]!4D=67S````````!005)?
M1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!0
M05)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X``````````%!!4E]#3$5!3CT````````Q`````````$Q)0E!!5$@`3$1?
M3$E"4D%265]0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%4
M2`````````!32$Q)0E]0051(````````55-%4@````!365-414T``"]T;7``
M````5$U01$E2``!414U01$E2`%1%35``````5$U0``````!54T523D%-10``
M````````)3`R>``````E<R5S)7,E<P``````````<&%R+0`````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*````````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````$%21U8`````
M&`````````!P97)L`````#``````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90``
M`````"TM````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M
M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O
M;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E
M8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I
M<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S
M92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H
M870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W
M96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@
M(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M
M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI
M8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI
M;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@
M<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O
M8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@
M8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K
M92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G
M=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M
M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@
M("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S
M;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M
M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@
M("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@
M("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@
M>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H
M*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?
M05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?
M(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[
M4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]
M"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O
M9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@
M('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H
M96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@
M<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@
M)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F
M+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@
M("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@
M:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@
M("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H
M;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?
M=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM0
M05)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@
M("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R
M8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L
M"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U
M8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@
M("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@
M(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K
M97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@
M("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@
M("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F
M:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@
M7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT[
M"B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@
M)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*
M"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@
M:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N
M;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H
M:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@
M=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D
M;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER
M92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S
M=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN
M9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S
M=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET
M:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I
M<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@
M:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@
M("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@
M*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M
M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@
M(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS
M=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB
M=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N
M9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,[
M"B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@
M("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H
M($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@
M)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2![
M"B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@
M)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@
M)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@
M("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N
M86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!
M4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@
M<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@
M("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A
M9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E
M("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF
M="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R
M*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A
M;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D
M(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@
M("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*
M"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO
M8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@
M("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*
M"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@
M8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_
M(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@
M("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV
M*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@
M("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@
M("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@
M("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I
M;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C
M(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2![
M"B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*
M("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]
M('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I
M"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@
M("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E
M>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@
M1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R
M97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@
M82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES
M<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE
M('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@
M("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,[
M"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU
M97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N
M86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M
M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@
M("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@
M("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@
M("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@
M("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@
M("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@
M("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G
M:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@
M("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A
M;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X
M*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@
M(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M
M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@
M(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z
M.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@
M("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@
M("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@
M("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@
M("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@
M("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@
M("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@
M('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@
M("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)
M9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@
M*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R
M97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@
M(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q
M=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@
M0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R
M<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E
M($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@
M6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z
M.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O
M;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R
M97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@
M("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I
M;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC
M(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E
M=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U
M<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I
M('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@
M("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW
M:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@
M("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PH@("`@("`@(&UK9&ER("1S=&UP
M9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@
M("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@
M<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY
M("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@
M("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@
M("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@
M9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@
M("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[
M4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L
M(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]
M($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@
M/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA
M;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@
M("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I
M9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T
M=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@
M4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O
M9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@
M("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*
M("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@
M("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@
M(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@
M("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@
M("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I
M"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]
M"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A8
M6"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@
M("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@
M('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE
M=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1?
M?2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%
M3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.
M?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#
M3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,
M14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@
M("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I
M9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@
M('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*
M<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@
M;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA
M:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````^"5```````#()4``````````````````
M`0`````````!``````````$`````````#0(````````!`````````%P"````
M`````0````````"O`P````````P`````````&!Y````````-`````````*Q7
M0```````&0````````#`O4$``````!L`````````"``````````:````````
M`,B]00``````'``````````(`````````/7^_V\`````*`)````````%````
M`````&@00```````!@````````#H!4````````H`````````2@4````````+
M`````````!@`````````%0````````````````````,`````````Z+]!````
M```"`````````)`&````````%``````````'`````````!<`````````B!=`
M```````'`````````/@60```````"`````````"0``````````D`````````
M&`````````#^__]O`````)@60```````____;P`````#`````````/#__V\`
M````LA5`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#8O4$`````````````````````````````````
M````````````````,!Y````````P'D```````#`>0```````,!Y````````P
M'D```````#`>0```````,!Y````````P'D```````#`>0```````,!Y`````
M```P'D```````#`>0```````,!Y````````P'D```````#`>0```````,!Y`
M```````P'D```````#`>0```````,!Y````````P'D```````#`>0```````
M,!Y````````P'D```````#`>0```````,!Y````````P'D```````#`>0```
M````,!Y````````P'D```````#`>0```````,!Y````````P'D```````#`>
M0```````,!Y````````P'D```````#`>0```````,!Y````````P'D``````
M`#`>0```````,!Y````````P'D```````#`>0```````,!Y````````P'D``
M`````#`>0```````,!Y````````P'D```````#`>0```````,!Y````````P
M'D```````#`>0```````,!Y````````P'D```````#`>0```````,!Y`````
M```P'D```````#`>0```````,!Y````````P'D```````#`>0```````,!Y`
M```````P'D```````#`>0```````,!Y````````P'D```````#`>0```````
M,!Y````````P'D```````#`>0```````,!Y`````````````````````````
M````_____P`````H7$```````$=#0SH@*%5B=6YT=2],:6YA<F\@-"XX+C(M
M,31U8G5N='4Q*2`T+C@N,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR
M96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O
M="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````,@!0```````R`$````````;````````````
M`````````0```````````````````!,````'`````@````````#D`4``````
M`.0!````````(`````````````````````0````````````````````A````
M!P````(`````````!`)````````$`@```````"0````````````````````$
M````````````````````-````/;__V\"`````````"@"0```````*`(`````
M``#``P````````4`````````"````````````````````#X````+`````@``
M``````#H!4```````.@%````````@`H````````&`````0````@`````````
M&`````````!&`````P````(`````````:!!```````!H$````````$H%````
M```````````````!````````````````````3@```/___V\"`````````+(5
M0```````LA4```````#@``````````4``````````@`````````"````````
M`%L```#^__]O`@````````"8%D```````)@6````````8``````````&````
M`P````@```````````````````!J````!`````(`````````^!9```````#X
M%@```````)``````````!0`````````(`````````!@`````````=`````0`
M```"`````````(@70```````B!<```````"0!@````````4````,````"```
M```````8`````````'X````!````!@`````````8'D```````!@>````````
M%`````````````````````0```````````````````!Y`````0````8`````
M````,!Y````````P'@```````(`$```````````````````0`````````!``
M````````A`````$````&`````````+`B0```````L"(```````#\-```````
M````````````"````````````````````(H````!````!@````````"L5T``
M`````*Q7````````$`````````````````````0```````````````````"0
M`````0````(`````````P%=```````#`5P```````!A@````````````````
M```(````````````````````F`````$````"`````````-BW0```````V+<`
M```````$````````````````````!````````````````````*(````.````
M`P````````#`O4$``````,"]````````"`````````````````````@`````
M``````````````"N````#P````,`````````R+U!``````#(O0````````@`
M```````````````````(````````````````````N@````$````#````````
M`-"]00``````T+T````````(````````````````````"```````````````
M`````+\````&`````P````````#8O4$``````-B]``````````(````````&
M``````````@`````````$`````````#(`````0````,`````````V+]!````
M``#8OP```````!`````````````````````(``````````@`````````S0``
M``$````#`````````.B_00``````Z+\```````!(`@``````````````````
M"``````````(`````````-8````!`````P`````````PPD$``````##"````
M````(`````````````````````@```````````````````#<````"`````,`
M````````4,)!``````!0P@```````%@0```````````````````(````````
M````````````X0````$````P````````````````````4,(````````K````
M`````````````````0`````````!``````````$````#````````````````
M`````````'O"````````Z@````````````````````$`````````````````
>```!```````,`%`>0```````````````````)'@`
